"""Module Entity TeamPlayer"""
from sqlalchemy import  Integer,  PrimaryKeyConstraint, ForeignKey
from sqlalchemy.orm import Mapped, mapped_column
from .base import Base


class TeamPlayer(Base):
    """Entity TEAM_PLAYER"""
    __tablename__ = 'TEAM_PLAYER'
    player_id: Mapped[int] = mapped_column(Integer, ForeignKey('PLAYER.UUID'), name='PLAYER_ID')
    team_id: Mapped[int] = mapped_column(Integer, ForeignKey('TEAM.UUID'), nullable=False, name='TEAM_ID')



    __table_args__ = (
        PrimaryKeyConstraint('PLAYER_ID', 'TEAM_ID', name='team_player_pk'),
    )


from sqlalchemy import String, Integer
from sqlalchemy.orm import Mapped, mapped_column
from .base import Base


class Country(Base):
    __tablename__ = 'COUNTRY'
    id:Mapped[int]= mapped_column(Integer,autoincrement=True, primary_key=True,unique=True,nullable=False,name='ID',)
    name:Mapped[str]= mapped_column(String(255), name='NAME')
    code:Mapped[str]= mapped_column(String(255), name='CODE')



from sqlalchemy import String, Integer, ForeignKey
from sqlalchemy.orm import Mapped, relationship,mapped_column
from .base import Base
from .country import Country


class Department(Base):
    __tablename__ = 'DEPARTMENT'
    id:Mapped[int]= mapped_column(Integer,autoincrement=True, primary_key=True,unique=True,nullable=False,name='ID',)
    name:Mapped[str]= mapped_column(String(255), name='NAME')
    code:Mapped[str]= mapped_column(String(255), name='CODE')
    country_id:Mapped[int]= mapped_column(Integer, ForeignKey('COUNTRY.ID'), name='COUNTRY_ID')

    #country:Mapped[Country]= relationship('Country', back_populates='DEPARTMENT')



"""Module Entity Team"""
from datetime import datetime
from sqlalchemy import String, Integer, DateTime,ForeignKey
from sqlalchemy.orm import Mapped, mapped_column
from .base import Base


class Team(Base):
    """Entity Team"""
    __tablename__ = 'Team'
    uuid:Mapped[int]= mapped_column(String(255), primary_key=True,unique=True,nullable=False,name='UUID')
    city_id: Mapped[int] = mapped_column(Integer, ForeignKey('CITY.ID'), name='CITY_ID')
    coach_id: Mapped[int] = mapped_column(Integer, ForeignKey('PLAYER.UUID'), name='COACH_ID')
    captain: Mapped[int] = mapped_column(Integer, ForeignKey('PLAYER.UUID'), nullable=False, name='CAPTAIN_ID')
    category:Mapped[str]= mapped_column(String(255), name='CATEGORY')
    name:Mapped[str]= mapped_column(String(500), unique=True,nullable=False,name='NAME')
    created_at: Mapped[datetime] = mapped_column(DateTime, default=datetime.now, name='CREATED_AT')
    updated_at: Mapped[datetime] = mapped_column(DateTime, default=datetime.now, onupdate=datetime.now, name='UPDATED_AT')